<!--- Copyright 2022 eprbell --->

<!--- Licensed under the Apache License, Version 2.0 (the "License"); --->
<!--- you may not use this file except in compliance with the License. --->
<!--- You may obtain a copy of the License at --->

<!---     http://www.apache.org/licenses/LICENSE-2.0 --->

<!--- Unless required by applicable law or agreed to in writing, software --->
<!--- distributed under the License is distributed on an "AS IS" BASIS, --->
<!--- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. --->
<!--- See the License for the specific language governing permissions and --->
<!--- limitations under the License. --->

# Contributing to Prezzemolo

## Table of Contents
* **[Reporting Bugs](#reporting-bugs)**
* **[Contributing to the Repository](#contributing-to-the-repository)**
  * [Submitting Pull Requests](#submitting-pull-requests)
* **[Contributing with an Ecosystem Project](#contributing-with-an-ecosystem-project)**

## Reporting Bugs
Feel free to submit bugs via [Issue Tracker](https://github.com/eprbell/prezzemolo/issues).

## Contributing to the Repository
Read the [developer guide](README.dev.md), which describes setup instructions, development workflow, design principles, source tree structure, etc.

### Submitting Pull Requests
Feel free to submit pull requests. Please follow these practices:
* follow the Prezzemolo [design guidelines](README.dev.md#design-guidelines)
* follow the [PEP 8](https://www.python.org/dev/peps/pep-0008/) coding standard;
* add [unit tests](tests/) for any new code;
* ensure your commits are atomic (one feature per commit);
* write a clear log message for your commits.
